DemoPackage Package — DemoPackage 0.0.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- DemoPackage 0.0.1 documentation »

# DemoPackage Package

## `DemoPackage` Package

### DemoPackage

> This is a demo module for the DemoPackage:
>   - Author - Sourabh Bajaj.
>   - Email - sourabhbajaj@gatech.edu.
>   - License - BSD License.

## `utils` Module

Utility functions.

`DemoPackage.utils.` `main`()

  This is the main function

`DemoPackage.utils.` `print_integer`(i=100)

  This function prints the integer i.

  Parameters: | i – The integer to be printed.
  Returns: | None.
  Return type: | None.
  Output : | print an integer

`DemoPackage.utils.` `print_string`()

  This function prints a string.

  Returns: | None.
  Output : | print an string.
  Return type: | None.

## Subpackages

- tests Package
  - `test_utils` Module

### Navigation

- index
- modules |
- next |
- previous |
- DemoPackage 0.0.1 documentation »